autowisp.source_finder_util module — AutoWISP documentation

# autowisp.source_finder_util module

## Class Inheritance Diagram

Some general purpose low level tools for source extraction.

autowisp.source_finder_util.get_srcextract_columns(tool)

  Return a list of the columns in the output source extraction file.

autowisp.source_finder_util.start_fistar(unpacked_fits_fname, threshold, stdout=-1)

  Find sources in the given frame using fistar.

autowisp.source_finder_util.start_hatphot(unpacked_fits_fname, threshold, stdout=-1)

  Find sources in the given frame using hatphot.